@@ -1,6 +1,7 @@
 from Products.Five import BrowserView
 from Products.CMFCore.utils import getToolByName
 import json
+from AccessControl import getSecurityManager
 
 try:
     from collective.flowplayer.interfaces import IFlowPlayable
@@ -140,7 +141,10 @@ class MediaShowListingView(BrowserView):
         path = '/'.join(item.getPhysicalPath())
         
         if item.portal_type == "Folder" or (item.restrictedTraverse('@@plone').isStructuralFolder()  and item.portal_type != "Topic" and item.portal_type != "Category Navigator"):
-            results = catalog.searchResults(path = { 'query' : path, 'depth' : 1 }, sort_on = 'getObjPositionInParent')
+            if not recursiveMode:
+                results = catalog.searchResults(path = { 'query' : path, 'depth' : 1 }, sort_on = 'getObjPositionInParent')
+            else:
+                results = catalog.searchResults(path = { 'query' : path}, sort_on = 'getObjPositionInParent')
         elif item.portal_type == "Topic":
             if item.limitNumber:
                 results = catalog.searchResults(item.buildQuery())[:item.itemCount]
@@ -162,7 +166,7 @@ class MediaShowListingView(BrowserView):
         
         #Python to JSON encoding
         for res in results:
-            if self.getMediaURL(res.getObject()) != "":
+            if self.getMediaURL(res.getObject()) != "" and self.canView(res.getObject()) :
                 resultArray.append({"url": res.getURL(), "UID": res["UID"]})
 
         jsonStr = json.dumps(resultArray[:100])
@@ -209,32 +213,26 @@ class MediaShowListingView(BrowserView):
         if item.portal_type == 'Image':
             return item.absolute_url()
         
-        if recursiveMode:   
-            catalog = getToolByName(self.context, 'portal_catalog')
-            plone_utils = getToolByName(self.context, 'plone_utils')
-            path = '/'.join(item.getPhysicalPath())
-            
-            if plone_utils.isStructuralFolder(item):
-                results = catalog.searchResults(path = {'query' : path,'depth' : 1 }, type = ['Image', 'File', 'Link'], sort_on = 'getObjPositionInParent')
-                if len(results) > 0:
-                    leadMedia = results[0]
-                    if leadMedia.portal_type == 'Image':
-                        return leadMedia.getURL() + '/image_large'
-                    elif leadMedia.portal_type == 'Link':
-                        return leadMedia.remoteUrl
-                    else:
-                        return leadMedia.getURL()
-                else:
-                    return ""
-            else:
-                #TODO: Add lead image support and News Item Image support
-                return ""
-        else:
-            return ""
+        return ""
         
     def isVideo(self, item):
         if FLOWPLAYER_EXISTS:
             result = IFlowPlayable.providedBy(item)
         else:
             result = False
-        return result
\ No newline at end of file
+        return result
+    
+    def canView(self, object):
+        permission = "View"
+        try:
+          if not object.acquiredRolesAreUsedBy( permission ):
+            for p in object.rolesOfPermission( permission ):
+              if p['selected']:
+                if p['name'] in user.getRoles():
+                  return 1
+          else:
+           return 1
+        except:
+            pass
+        return 0
+
